@@ -126,7 +126,7 @@ async def extract_message(message):
 
 
 async def fetch_message_from_id(guild, channel_id, message_id):
-    channel = guild.get_channel(channel_id)
+    channel = guild.get_channel_or_thread(channel_id)
     message = await channel.fetch_message(message_id)
     return message
 
